@@ -140,7 +140,8 @@ class EA(AbstractEA):
             algorithm = f(**args)
 
         if self.visualizer:
-            algorithm.observable.register(observer=VisualizerObserver())
+            axis_labels = [f.short_str() for f in self.problem.fevaluation]
+            algorithm.observable.register(observer=VisualizerObserver(axis_labels=axis_labels))
         algorithm.observable.register(observer=PrintObjectivesStatObserver())
         self.algorithm = algorithm
         algorithm.run()
